@@ -1,6 +1,6 @@
 import sys
 from pathlib import Path
-from typing import Generator, Tuple
+from typing import Generator, Tuple, Optional
 
 from .ffi import ffi, load_hostfxr
 from .types import Runtime, RuntimeInfo, StrOrPath
@@ -12,21 +12,41 @@ _IS_SHUTDOWN = False
 
 
 class DotnetCoreRuntime(Runtime):
-    def __init__(self, runtime_config: Path, dotnet_root: Path, **params: str):
+    _version: str
+
+    def __init__(
+        self,
+        *,
+        dotnet_root: Path,
+        runtime_config: Optional[Path] = None,
+        entry_dll: Optional[Path] = None,
+        **params: str,
+    ):
+        self._handle = None
+
         if _IS_SHUTDOWN:
             raise RuntimeError("Runtime can not be reinitialized")
 
         self._dotnet_root = Path(dotnet_root)
         self._dll = load_hostfxr(self._dotnet_root)
-        self._is_initialized = False
-        self._handle = _get_handle(self._dll, self._dotnet_root, runtime_config)
-        self._load_func = _get_load_func(self._dll, self._handle)
+        self._load_func = None
+
+        if runtime_config is not None:
+            self._handle = _get_handle_for_runtime_config(
+                self._dll, self._dotnet_root, runtime_config
+            )
+        elif entry_dll is not None:
+            self._handle = _get_handle_for_dotnet_command_line(
+                self._dll, self._dotnet_root, entry_dll
+            )
+        else:
+            raise ValueError("Either runtime_config or entry_dll must be provided")
 
         for key, value in params.items():
             self[key] = value
 
         # TODO: Get version
-        self._version = "<undefined>"
+        self._version: str = "<undefined>"
 
     @property
     def dotnet_root(self) -> Path:
@@ -34,7 +54,7 @@ class DotnetCoreRuntime(Runtime):
 
     @property
     def is_initialized(self) -> bool:
-        return self._is_initialized
+        return self._load_func is not None
 
     @property
     def is_shutdown(self) -> bool:
@@ -79,10 +99,15 @@ class DotnetCoreRuntime(Runtime):
         for i in range(size_ptr[0]):
             yield (decode(keys_ptr[i]), decode(values_ptr[i]))
 
+    def _get_load_func(self):
+        if self._load_func is None:
+            self._load_func = _get_load_func(self._dll, self._handle)
+
+        return self._load_func
+
     def _get_callable(self, assembly_path: StrOrPath, typename: str, function: str):
         # TODO: Maybe use coreclr_get_delegate as well, supported with newer API
         # versions of hostfxr
-        self._is_initialized = True
 
         # Append assembly name to typename
         assembly_path = Path(assembly_path)
@@ -90,7 +115,7 @@ class DotnetCoreRuntime(Runtime):
         typename = f"{typename}, {assembly_name}"
 
         delegate_ptr = ffi.new("void**")
-        res = self._load_func(
+        res = self._get_load_func()(
             encode(str(assembly_path)),
             encode(typename),
             encode(function),
@@ -101,14 +126,8 @@ class DotnetCoreRuntime(Runtime):
         check_result(res)
         return ffi.cast("component_entry_point_fn", delegate_ptr[0])
 
-    def _check_initialized(self) -> None:
-        if self._handle is None:
-            raise RuntimeError("Runtime is shut down")
-        elif not self._is_initialized:
-            raise RuntimeError("Runtime is not initialized")
-
     def shutdown(self) -> None:
-        if self._handle is not None:
+        if self._handle and self._dll:
             self._dll.hostfxr_close(self._handle)
             self._handle = None
 
@@ -122,7 +141,9 @@ class DotnetCoreRuntime(Runtime):
         )
 
 
-def _get_handle(dll, dotnet_root: StrOrPath, runtime_config: StrOrPath):
+def _get_handle_for_runtime_config(
+    dll, dotnet_root: StrOrPath, runtime_config: StrOrPath
+):
     params = ffi.new("hostfxr_initialize_parameters*")
     params.size = ffi.sizeof("hostfxr_initialize_parameters")
     # params.host_path = ffi.new("char_t[]", encode(sys.executable))
@@ -140,6 +161,29 @@ def _get_handle(dll, dotnet_root: StrOrPath, runtime_config: StrOrPath):
     return handle_ptr[0]
 
 
+def _get_handle_for_dotnet_command_line(
+    dll, dotnet_root: StrOrPath, entry_dll: StrOrPath
+):
+    params = ffi.new("hostfxr_initialize_parameters*")
+    params.size = ffi.sizeof("hostfxr_initialize_parameters")
+    params.host_path = ffi.NULL
+    dotnet_root_p = ffi.new("char_t[]", encode(str(Path(dotnet_root))))
+    params.dotnet_root = dotnet_root_p
+
+    handle_ptr = ffi.new("hostfxr_handle*")
+
+    args_ptr = ffi.new("char_t*[1]")
+    arg_ptr = ffi.new("char_t[]", encode(str(Path(entry_dll))))
+    args_ptr[0] = arg_ptr
+    res = dll.hostfxr_initialize_for_dotnet_command_line(
+        1, args_ptr, params, handle_ptr
+    )
+
+    check_result(res)
+
+    return handle_ptr[0]
+
+
 def _get_load_func(dll, handle):
     delegate_ptr = ffi.new("void**")
 
